@@ -1,5 +1,5 @@
 import sys
-
+import os
 from setuptools_scm import integration
 from setuptools_scm.utils import do, has_command
 from setuptools_scm import git
@@ -7,21 +7,14 @@ import pytest
 from datetime import datetime
 from os.path import join as opj
 from setuptools_scm.file_finder_git import git_find_files
-import warnings
+from datetime import date
 
 
-skip_if_win_27 = pytest.mark.skipif(
-    sys.platform == "win32" and sys.version_info[0] < 3,
-    reason="Not supported on Windows + Python 2.7",
+pytestmark = pytest.mark.skipif(
+    not has_command("git", warn=False), reason="git executable not found"
 )
 
 
-with warnings.catch_warnings():
-    warnings.filterwarnings("ignore")
-    if not has_command("git"):
-        pytestmark = pytest.mark.skip(reason="git executable not found")
-
-
 @pytest.fixture
 def wd(wd, monkeypatch):
     monkeypatch.delenv("HOME", raising=False)
@@ -50,7 +43,7 @@ def test_root_relative_to(tmpdir, wd, monkeypatch):
     p = wd.cwd.joinpath("sub/package")
     p.mkdir(parents=True)
     p.joinpath("setup.py").write_text(
-        u"""from setuptools import setup
+        """from setuptools import setup
 setup(use_scm_version={"root": "../..",
                        "relative_to": __file__})
 """
@@ -59,6 +52,12 @@ setup(use_scm_version={"root": "../..",
     assert res == "0.1.dev0"
 
 
+def test_git_gone(wd, monkeypatch):
+    monkeypatch.setenv("PATH", str(wd.cwd / "not-existing"))
+    with pytest.raises(EnvironmentError, match="'git' was not found"):
+        git.parse(str(wd.cwd), git.DEFAULT_DESCRIBE)
+
+
 @pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/298")
 @pytest.mark.issue(403)
 def test_file_finder_no_history(wd, caplog):
@@ -76,6 +75,8 @@ def test_parse_call_order(wd):
 def test_version_from_git(wd):
     assert wd.version == "0.1.dev0"
 
+    assert git.parse(str(wd.cwd), git.DEFAULT_DESCRIBE).branch == "master"
+
     wd.commit_testfile()
     assert wd.version.startswith("0.1.dev1+g")
     assert not wd.version.endswith("1-")
@@ -121,15 +122,21 @@ def test_git_worktree(wd):
 
 
 @pytest.mark.issue(86)
-def test_git_dirty_notag(wd):
+@pytest.mark.parametrize("today", [False, True])
+def test_git_dirty_notag(today, wd, monkeypatch):
+    if today:
+        monkeypatch.delenv("SOURCE_DATE_EPOCH", raising=False)
     wd.commit_testfile()
     wd.write("test.txt", "test2")
     wd("git add test.txt")
     assert wd.version.startswith("0.1.dev1")
-    # the date on the tag is in UTC
-    today = datetime.utcnow().date()
+    if today:
+        # the date on the tag is in UTC
+        tag = datetime.utcnow().date().strftime(".d%Y%m%d")
+    else:
+        tag = ".d20090213"
     # we are dirty, check for the tag
-    assert today.strftime(".d%Y%m%d") in wd.version
+    assert tag in wd.version
 
 
 @pytest.mark.issue(193)
@@ -192,7 +199,6 @@ def test_alphanumeric_tags_match(wd):
     assert wd.version.startswith("0.1.dev1+g")
 
 
-@skip_if_win_27
 def test_git_archive_export_ignore(wd, monkeypatch):
     wd.write("test1.txt", "test")
     wd.write("test2.txt", "test")
@@ -208,7 +214,6 @@ def test_git_archive_export_ignore(wd, monkeypatch):
     assert integration.find_files(".") == [opj(".", "test1.txt")]
 
 
-@skip_if_win_27
 @pytest.mark.issue(228)
 def test_git_archive_subdirectory(wd, monkeypatch):
     wd("mkdir foobar")
@@ -219,7 +224,6 @@ def test_git_archive_subdirectory(wd, monkeypatch):
     assert integration.find_files(".") == [opj(".", "foobar", "test1.txt")]
 
 
-@skip_if_win_27
 @pytest.mark.issue(251)
 def test_git_archive_run_from_subdirectory(wd, monkeypatch):
     wd("mkdir foobar")
@@ -254,6 +258,7 @@ def test_not_matching_tags(wd):
 
 
 @pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/411")
+@pytest.mark.xfail(reason="https://github.com/pypa/setuptools_scm/issues/449")
 def test_non_dotted_version(wd):
     wd.commit_testfile()
     wd("git tag apache-arrow-1")
@@ -261,12 +266,44 @@ def test_non_dotted_version(wd):
     assert wd.get_version().startswith("2")
 
 
+def test_non_dotted_version_with_updated_regex(wd):
+    wd.commit_testfile()
+    wd("git tag apache-arrow-1")
+    wd.commit_testfile()
+    assert wd.get_version(tag_regex=r"^apache-arrow-([\.0-9]+)$").startswith("2")
+
+
+def test_non_dotted_tag_no_version_match(wd):
+    wd.commit_testfile()
+    wd("git tag apache-arrow-0.11.1")
+    wd.commit_testfile()
+    wd("git tag apache-arrow")
+    wd.commit_testfile()
+    assert wd.get_version().startswith("0.11.2.dev2")
+
+
 @pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/381")
 def test_gitdir(monkeypatch, wd):
-    """
-    """
+    """"""
     wd.commit_testfile()
     normal = wd.version
     # git hooks set this and break subsequent setuptools_scm unless we clean
     monkeypatch.setenv("GIT_DIR", __file__)
     assert wd.version == normal
+
+
+def test_git_getdate(wd):
+    # TODO: case coverage for git wd parse
+    today = date.today()
+
+    def parse_date():
+        return git.parse(os.fspath(wd.cwd)).node_date
+
+    git_wd = git.GitWorkdir(os.fspath(wd.cwd))
+    assert git_wd.get_head_date() is None
+    assert parse_date() == today
+
+    wd.commit_testfile()
+    assert git_wd.get_head_date() == today
+    meta = git.parse(os.fspath(wd.cwd))
+    assert meta.node_date == today
